/****************************************************************
 * Copyright 2004 All rights reserved                                *
 * HI Corporation and Sony Ericsson Mobile Communications AB         *
 *                                                                   *
 * The software is the copyrighted work of HI Corporation with       *
 * modifications from Sony Ericsson Mobile Communications AB.        *
 *                                                                   *
 * The use of the software is subject to the terms of the            *
 * end-user license agreement which accompanies or is included       *
 * with the software. The software is provided "as is" and Sony      *
 * Ericsson specifically disclaim any warranty or condition          *
 * whatsoever regarding merchantability or fitness for a             *
 * specific purpose, title or non-infringement. No warranty of       *
 * any kind is made in relation to the condition, suitability,       *
 * availability, accuracy, reliability, merchantability and/or       *
 * non-infringement of the software provided herein                  *
 ****************************************************************/

import javax.microedition.lcdui.Display;
import javax.microedition.midlet.MIDlet;

/**
 * Shows how to use MascotCapsule v3 for showing and rotating
 * 3D models.
 *
 * Rotating the 3D objects is used to let the user change
 * his viewing perspective because it's easier to rotate all objects
 * than it is to rotate the 3D camera.
 *
 * The Model has two different animations. Switch between
 * these by soft key "Change" and rotate the
 * world/models with the joystick.
 *
 */
public class MascotCapsuleDemo extends MIDlet implements Runnable
{
   /**
    * Drawing canvas of this midlet
    */
    private Canvas3D canvas;

   /**
    * Display used by the midlet
    */
    private Display  display;

   /**
    * Boolean flag indicating that midlet is started
    */
    private boolean  started = false;

   /**
    * Boolean flag indicating that midlet is paused
    */
    private boolean paused = false;

    /**
     * Thread which performs an animation loop
     */
    private Thread prThread;

    /**
     * Create a new MascotCapsuleDemo midlet
     */
    public MascotCapsuleDemo()
    {
        display  = Display.getDisplay(this);
        canvas = new Canvas3D(this);
        prThread = new Thread(this);
    }

    /**
     * startApp()
     */
    public void startApp()
    {
        display.setCurrent(canvas);
        if (!started)
        {
            prThread.start();
            started = true;
        }
    }

    /**
     * pauseApp()
     */
    public void pauseApp() {}

    /**
     * destroyApp()
     */
    public void destroyApp(boolean unconditional)
    {
        canvas.clearResource();
        this.notifyDestroyed();
    }

    /**
     * Run an animation loop
     */
    public void run()
    {
        while (canvas.resourcesAreLoaded())
        {
            if (!paused)
            {
                canvas.processPaint();
            }

            try
            {
              Thread.sleep(10);
            }
            catch (InterruptedException e)
            {
            }

            if (!paused)
            {
                canvas.processKeyState();
            }
        }
    }
}
